Class: PayDirt::Base
Overview
A developer can optionally inherit from this base class, rather than include the PayDirt::UseCase module -- this is obviously not possible if your service object's class is already inheriting from another class.
A developer can optionally inherit from this base class, rather than include the PayDirt::UseCase module -- this is obviously not possible if your service object's class is already inheriting from another class.